==> gazie7.30.zip: gazie/modules/acquis/menu.english.php <==
<?php

/*
  --------------------------------------------------------------------------
  GAzie - Gestione Azienda
  Copyright (C) 2004-2020 - Antonio De Vincentiis Montesilvano (PE)
  (http://www.devincentiis.it)
  <http://gazie.sourceforge.net>
  --------------------------------------------------------------------------
  Questo programma e` free software;   e` lecito redistribuirlo  e/o
  modificarlo secondo i  termini della Licenza Pubblica Generica GNU
  come e` pubblicata dalla Free Software Foundation; o la versione 2
  della licenza o (a propria scelta) una versione successiva.

  Questo programma  e` distribuito nella speranza  che sia utile, ma
  SENZA   ALCUNA GARANZIA; senza  neppure  la  garanzia implicita di
  NEGOZIABILITA` o di  APPLICABILITA` PER UN  PARTICOLARE SCOPO.  Si
  veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.

  Ognuno dovrebbe avere   ricevuto una copia  della Licenza Pubblica
  Generica GNU insieme a   questo programma; in caso  contrario,  si
  scriva   alla   Free  Software Foundation, 51 Franklin Street,
  Fifth Floor Boston, MA 02110-1335 USA Stati Uniti.
  --------------------------------------------------------------------------
 */
$transl['acquis'] = array('name' => "Purchases",
    'title' => "Purchases Management",
    'm2' => array(1 => array("Management of orders and estimates from suppliers", "Estimate and Order"),
        2 => array("Management of delivery notes from suppliers", "Delivery notes"),
        3 => array("Management purchases Invoice", "Purchases Invoice"),
        4 => array("Report of accounts payable", "Accounts payable"),
        5 => array("Suppliers management", "Suppliers"),
        6 => array("View and print debit report", "Debit report"),
        7 => array("Print fuel note", "Fuel note"),
        8 => array("Scadenzario a partite aperte", "Scadenzario"),
        9 => array("Agenti di Fornitori", "Agenti")
    ),
    'm3' => array(1 => array("Ask for a quote to supplier", "Ask a quote"),
        2 => array("Order to supplier", "Order to supplier"),
        3 => array("Issue Delivery notes to become a supplier", "Delivery notes to become"),
        4 => array("Issue Delivery notes for processing", "Delivery notes for processing"),
        5 => array("Registration of purchase invoice", "Enter invoice"),
        6 => array("Registration of purchase credit note", "Enter credit note"),
        7 => array("Accounting of purchase invoices", "Accounting invoices"),
        8 => array("Insert new supplier", "New supplier"),
        9 => array("Lista D.d.T. d'acqisto", "Report of Delivery notes"),
        10 => array("Ricevuto DdT da fornitore", "New Delivery notes"),
        11 => array("Debt payment towards supplier", "Debt payment towards supplier"),
        12 => array("Report partite aperte", "Report partite aperte"),
        13 => array("Selezione e stampa stato clienti", "Stato delle scadenze"),
        14 => array("Inserimento nuovo agente di fornitori", "Nuovo agente"),
        15 => array("Print customers list", "Customers list"),
        16 => array("Purchase depreciable asset", "Purchase depreciable asset"),
        17 => array("Pagamento RiBa fornitori", "Paga RiBa a fornitori"),
		18 => array("Automatic vendor order", "Automatic vendor order"),
		19 => array("Acquisisci fattura elettronica", "Acquisisci fattura elettronica"),
        20 => array("Ricevuto DdT ritorno da lavorazione", "Ricevuto DdT ritorno da lavorazione")
    )
);
?>

==> gazie8.00.zip: gazie/modules/acquis/menu.english.php <==
<?php

/*
  --------------------------------------------------------------------------
  GAzie - Gestione Azienda
  Copyright (C) 2004-2021 - Antonio De Vincentiis Montesilvano (PE)
  (http://www.devincentiis.it)
  <http://gazie.sourceforge.net>
  --------------------------------------------------------------------------
  Questo programma e` free software;   e` lecito redistribuirlo  e/o
  modificarlo secondo i  termini della Licenza Pubblica Generica GNU
  come e` pubblicata dalla Free Software Foundation; o la versione 2
  della licenza o (a propria scelta) una versione successiva.

  Questo programma  e` distribuito nella speranza  che sia utile, ma
  SENZA   ALCUNA GARANZIA; senza  neppure  la  garanzia implicita di
  NEGOZIABILITA` o di  APPLICABILITA` PER UN  PARTICOLARE SCOPO.  Si
  veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.

  Ognuno dovrebbe avere   ricevuto una copia  della Licenza Pubblica
  Generica GNU insieme a   questo programma; in caso  contrario,  si
  scriva   alla   Free  Software Foundation, 51 Franklin Street,
  Fifth Floor Boston, MA 02110-1335 USA Stati Uniti.
  --------------------------------------------------------------------------
 */
$transl['acquis'] = array('name' => "Purchases",
    'title' => "Purchases Management",
    'm2' => array(1 => array("Management of orders and estimates from suppliers", "Estimate and Order"),
        2 => array("Management of delivery notes from suppliers", "Delivery notes"),
        3 => array("Management purchases Invoice", "Purchases Invoice"),
        4 => array("Report of accounts payable", "Accounts payable"),
        5 => array("Suppliers management", "Suppliers"),
        6 => array("View and print debit report", "Debit report"),
        7 => array("Print fuel note", "Fuel note"),
        8 => array("Scadenzario a partite aperte", "Scadenzario"),
        9 => array("Agenti di Fornitori", "Agenti"),
        10 => array("Gestione Ordini a Fornitori", "Ordini")
    ),
    'm3' => array(1 => array("Ask for a quote to supplier", "Ask a quote"),
        2 => array("Order to supplier", "Order to supplier"),
        3 => array("Issue Delivery notes to become a supplier", "Delivery notes to become"),
        4 => array("Issue Delivery notes for processing", "Delivery notes for processing"),
        5 => array("Registration of purchase invoice", "Enter invoice"),
        6 => array("Registration of purchase credit note", "Enter credit note"),
        7 => array("Accounting of purchase invoices", "Accounting invoices"),
        8 => array("Insert new supplier", "New supplier"),
        9 => array("Lista D.d.T. d'acqisto", "Report of Delivery notes"),
        10 => array("Ricevuto DdT da fornitore", "New Delivery notes"),
        11 => array("Debt payment towards supplier", "Debt payment towards supplier"),
        12 => array("Report partite aperte", "Report partite aperte"),
        13 => array("Selezione e stampa stato clienti", "Stato delle scadenze"),
        14 => array("Inserimento nuovo agente di fornitori", "Nuovo agente"),
        15 => array("Print customers list", "Customers list"),
        16 => array("Purchase depreciable asset", "Purchase depreciable asset"),
        17 => array("Pagamento RiBa fornitori", "Paga RiBa a fornitori"),
		18 => array("Automatic vendor order", "Automatic vendor order"),
		19 => array("Acquisisci fattura elettronica", "Acquisisci fattura elettronica"),
        20 => array("Ricevuto DdT ritorno da lavorazione", "Ricevuto DdT ritorno da lavorazione"),
        21 => array("Genera XML-CBI bonifico", "Genera XML-CBI bonifico")
    )
);
?>
